@@ -60,18 +60,21 @@ class _RecordsEvents:
         consumer: AIOKafkaConsumer,
         records: Iterable[ConsumerRecord],
         message_send: Callable[[MessageSendEvent], Awaitable[None]],
+        ackable_consumer: bool,
     ) -> None:
         self._deque = deque(records)
         self._consumer = consumer
         self._message_send = message_send
         self._message_receive_ids: dict[str, dict[TopicPartition, int]] = {}
+        self._ackable_consumer = ackable_consumer
 
     async def receive(self) -> MessageReceiveEvent:
         record = self._deque.popleft()
         message_receive_id = f"{record.topic}:{record.partition}:{record.offset}"
-        self._message_receive_ids[message_receive_id] = {
-            TopicPartition(record.topic, record.partition): record.offset + 1
-        }
+        if self._ackable_consumer:
+            self._message_receive_ids[message_receive_id] = {
+                TopicPartition(record.topic, record.partition): record.offset + 1
+            }
 
         encoded_headers = [(key.encode(), value) for key, value in record.headers]
         message_receive_event: MessageReceiveEvent = {
@@ -85,7 +88,7 @@ class _RecordsEvents:
         return message_receive_event
 
     async def send(self, event: AMGISendEvent) -> None:
-        if event["type"] == "message.ack":
+        if event["type"] == "message.ack" and self._ackable_consumer:
             offsets = self._message_receive_ids.pop(event["id"])
             await self._consumer.commit(offsets)
         if event["type"] == "message.send":
@@ -106,6 +109,7 @@ class Server:
         self._topics = topics
         self._bootstrap_servers = bootstrap_servers
         self._group_id = group_id
+        self._ackable_consumer = self._group_id is not None
         self._producer: Optional[AIOKafkaProducer] = None
         self._producer_lock = Lock()
         self._stoppable = Stoppable()
@@ -138,7 +142,10 @@ class Server:
                     }
 
                     records_events = _RecordsEvents(
-                        self._consumer, records, self._message_send
+                        self._consumer,
+                        records,
+                        self._message_send,
+                        self._ackable_consumer,
                     )
 
                     await self._app(
